------------------------------------------------------------------------
--	Barrel
--	DataBroker display using minimap icons.
--	Copyright 2008, 2009 Copystring. All rights reserved.
--	http://www.wowace.com/addons/barrel/
------------------------------------------------------------------------

local BARREL, Barrel = ...

local LDB = LibStub("LibDataBroker-1.1")
local LDBI = LibStub("LibDBIcon-1.0")

------------------------------------------------------------------------

local L = setmetatable({}, { __index = function(t, k)
	local v = tostring(k)
	rawset(t, k, v)
	return v
end })
do
	local GAME_LOCALE = GetLocale()
	if GAME_LOCALE == "deDE" then
		L["Angle"] = "Winkel"
		L["Plugins"] = "Plugins"
		L["Show data sources"] = "Datenquellen anzeigen"
		L["Show launcher"] = "Programmstartern anzeigen"
		L["Show minimap icon"] = "Minikartensymbole anzeigen"
		L["Show plugins that provide only an icon."] = "Zeige Plugins, die nur ein Symbol zeigen."
		L["Show plugins that provide text or other data."] = "Zeige Plugins, die Text oder andere Daten zu zeigen."

	elseif GAME_LOCALE == "esES" or GAME_LOCALE == "esMX" then
		L["Angle"] = "Ángulo"
		L["Plugins"] = "Plugins"
		L["Show data sources"] = "Mostrar fuentes de datos"
		L["Show launcher"] = "Mostrar lanzadores"
		L["Show minimap icon"] = "Mostrar icono del minimapa"
		L["Show plugins that provide only an icon."] = "Mostrar plugins que sólo muestran un icono."
		L["Show plugins that provide text or other data."] = "Mostrar plugins que muestran texto u otros datos."

	elseif GAME_LOCALE == "frFR" then
		L["Angle"] = "Angle"
		L["Plugins"] = "Plugins"
		L["Show data sources"] = "Afficher sources de données"
		L["Show launchers"] = "Afficher lanceurs"
		L["Show minimap icon"] = "Afficher icône minicarte"
		L["Show plugins that provide only an icon."] = "Afficher plugins qui montrent que d'une icône."
		L["Show plugins that provide text or other data."] = "Afficher plugins qui montrent texte ou d'autres données."

	elseif GAME_LOCALE == "itIT" then
		L["Angle"] = "Angolo"
		L["Plugins"] = "Plugins"
		L["Show data sources"] = "Mostrare fonti di dati"
		L["Show launchers"] = "Mostrare lanciatori"
		L["Show minimap icon"] = "Mostrare icona sulla minimappa"
		L["Show plugins that provide only an icon."] = "Mostrare plugins che mostrano solo un'icona."
		L["Show plugins that provide text or other data."] = "Mostrare plugins che mostrano testo o altri dati."

	elseif GAME_LOCALE == "ptBR" then
		L["Angle"] = "Ângulo"
		L["Plugins"] = "Plugins"
		L["Show data sources"] = "Mostrar fontes de dados"
		L["Show launchers"] = "Mostrar lançadores"
		L["Show minimap icon"] = "Mostrar ícone no mini-mapa"
		L["Show plugins that provide only an icon."] = "Mostrar plugins que mostram apenas um ícone."
		L["Show plugins that provide text or other data."] = "Mostrar plugins que mostram texto ou outros dados."

	elseif GAME_LOCALE == "ruRU" then
		L["Angle"] = "Угол"
		L["Plugins"] = "Плагины"
		L["Show data sources"] = "Показать источники данных"
		L["Show launchers"] = "Показать пусковых установок"
		L["Show minimap icon"] = "Показать иконки на мини-карте"
		L["Show plugins that provide only an icon."] = "Показать плагины, которые показывают только иконку."
		L["Show plugins that provide text or other data."] = "Показать плагинов, которые показывают, текст или другие данные."

	elseif GAME_LOCALE == "koKR" then
		L["Angle"] = "직각"
		L["Plugins"] = "플러그인"
		L["Show data sources"] = "데이터 소스 표시"
		L["Show launchers"] = "실행 항목만 표시"
		L["Show minimap icon"] = "미니맵 아이콘 표시"
		--L["Show plugins that provide only an icon."] = ""
		--L["Show plugins that provide text or other data."] = ""

	elseif GAME_LOCALE == "zhCN" then
		L["Angle"] = "角"
		L["Plugins"] = "组件"
		L["Show data sources"] = "显示数据源"
		L["Show launchers"] = "显示仅运行"
		L["Show minimap icon"] = "显示小地圖圖示"
		--L["Show plugins that provide only an icon."] = ""
		--L["Show plugins that provide text or other data."] = ""

	elseif GAME_LOCALE == "zhTW" then
		L["Angle"] = "角"
		L["Plugins"] = "插件"
		L["Show data sources"] = "顯示數據源"
		L["Show launchers"] = "顯示僅運行"
		L["Show minimap icon"] = "顯示小地圖圖示"
		--L["Show plugins that provide only an icon."] = ""
		--L["Show plugins that provide text or other data."] = ""
	end
end

------------------------------------------------------------------------

local pluginOptions = {}

function Barrel:AddOptionsForPlugin(name)
	local menuName = string.gsub(name, "%s", "")
	pluginOptions[menuName] = {
		name = menuName,
		type = "group",
		--dialogInline = true,
		args = {
			enable = {
				name = L["Show minimap icon"],
				order = 1,
				width = "full",
				type = "toggle",
				get = function(info)
					local name = name
					return not self.db.profile[name].hide
				end,
				set = function(info, value)
					local name = name
					if value then
						self:EnableDataObject(name)
					else
						self:DisableDataObject(name)
					end
					self.db.profile[name].hide = not value
				end,
			},
			angle = {
				name = L["Angle"],
				order = 2,
				width = "double",
				type = "range",
				min = 0,
				max = 360,
				step = 1,
				get = function()
					return self.db.profile[name].minimapPos
				end,
				set = function(info, value)
					self.db.profile[name].minimapPos = value
					LDBI:Refresh("Barrel_" .. name)
				end,
			},
		},
	}
end

------------------------------------------------------------------------

function Barrel:LoadOptions()
	self.db = LibStub("AceDB-3.0"):New("BarrelDB", {
		profile = {
			showDataSources = true,
			showLaunchers = true,
		}
	}, "Default")

	local options = {
		type = "group",
		args = {
			options = {
				name = BARREL,
				order = 1,
				type = "group",
				args = {
					showDataSources = {
						name = L["Show data sources"],
						desc = L["Show plugins that provide text or other data."],
						width = "full",
						type = "toggle",
						get = function()
							return self.db.profile.showDataSources
						end,
						set = function(info, value)
							self.db.profile.showDataSources = value
							self:ToggleDataSources()
						end,
					},
					showLaunchers = {
						name = L["Show launchers"],
						desc = L["Show plugins that provide only an icon."],
						width = "full",
						type = "toggle",
						get = function()
							return self.db.profile.showLaunchers
						end,
						set = function(info, value)
							self.db.profile.showLaunchers = value
							self:ToggleLaunchers()
						end,
					},
				},
			},
			plugins = {
				name = L["Plugins"],
				order = 2,
				type = "group",
				childGroups = "tree",
				args = pluginOptions,
			},
		},
	}

	options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	options.args.profiles.order = 3

	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable(BARREL, options)
	self.options = options

	local ACD = LibStub("AceConfigDialog-3.0")
	self.optionsPanels = {
		[1] = ACD:AddToBlizOptions(BARREL, BARREL, nil, "options"),
		[2] = ACD:AddToBlizOptions(BARREL, options.args.plugins.name, BARREL, "plugins"),
		[3] = ACD:AddToBlizOptions(BARREL, options.args.profiles.name, BARREL, "profiles"),
	}

	SLASH_BARREL1 = "/br"
	SLASH_BARREL2 = "/barrel"

	SlashCmdList.BARREL = function()
		InterfaceOptionsFrame_OpenToCategory(self.optionsPanels[3])
		InterfaceOptionsFrame_OpenToCategory(self.optionsPanels[1])
	end
end